@@ -4,10 +4,9 @@ import logging
 import numpy as np
 import transformers
 
-from qary.constants import args
+from qary.config import CLI_ARGS
 from qary.skills.base import BotReply
-from qary.skills.base import ContextBot
-from qary.etl import wikipedia_api
+from qary.skills.base import ContextBaseSkill
 
 
 log = logging.getLogger(__name__)
@@ -15,10 +14,10 @@ log = logging.getLogger(__name__)
 STOP_WIKI_PROBABILITY = .4
 
 
-class Skill(ContextBot):
+class Skill(ContextBaseSkill):
     """ Skill that provides answers to questions given context data containing the answer """
 
-    def __init__(self, context=None, args=args, model=None, **kwargs):
+    def __init__(self, context=None, cli_args=CLI_ARGS, model=None, *args, **kwargs):
         """ Initialize a Question Answering skill using model supplied (default model=BERT)
 
         >>> qa = Skill()
@@ -30,10 +29,10 @@ class Skill(ContextBot):
         {'score': 0.9..., 'start': 0, 'end': 4, 'answer': 'Cain'}
         """
         context = {'doc': {'text': ''}}
-        super().__init__(context=context, args=args, **kwargs)
-        log.debug(f'Initial qa.Skill.context: {self.context}')
+        log.debug(f'Initial qa.Skill.context: {getattr(self, "context", None)}')
         self.model = transformers.pipeline('question-answering') if model is None else model
-        self.wikiscraper = wikipedia_api.WikiScraper()
+        # self.wikiscraper = wikititles.WikiScraper()
+        super().__init__(context=context, cli_args=cli_args, *args, **kwargs)
 
     def reply(self, statement, context=None, **kwargs):
         """ Use context document + BERT to answer question in statement
